/**
 * Copyright (c) 2011-2012, ReXSL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the ReXSL.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rexsl.maven;

import java.io.File;
import java.util.Set;

/**
 * Testing environment.
 *
 * @author Yegor Bugayenko (yegor@rexsl.com)
 * @version $Id: Environment.java 1078 2012-03-19 21:09:18Z guard $
 */
public interface Environment {

    /**
     * Get basedir of the project.
     * @return The basedir
     */
    File basedir();

    /**
     * Get web root, normally a directory in "target/" folder.
     * @return The web dir
     */
    File webdir();

    /**
     * Return a set of artifacts (JARs and dirs) that should be available
     * for all "running-as-remote" Groovy scripts.
     * @param tonly The list should include ONLY test-related artifacts?
     * @return The list of JARs and directories
     */
    Set<File> classpath(final boolean tonly);

    /**
     * Shall we use runtime filtering of web resources?
     * @return Shall we?
     */
    boolean useRuntimeFiltering();

    /**
     * Get port number, that can be used for a web container in runtime.
     * @return The port number, just allocated/reserved
     */
    int port();

}
